# declare used external funtions
function cspline;

# number of coefficients
param n:=7;
# number of knots (nk = n-1)
param nk:=6;
# knots vector
param knots{1..nk};

# initial guess for spaces
param hinit{1..n};

# coefficients
var h{j in 1..n}:=hinit[j];
# parameter
var tau:=0;

# initial and final velocity and acceleration
param vi:=0;
param vf:=0;
param ai:=13.880794;
param af:=-0.415203;

# to save some space we define a variable
#  which is the C-Spline
var g=cspline(tau*(sum {j in 1..n} (h[j])),1,n,
      {j in 1..n}h[j], {j in 1..nk}knots[j],vi,vf,ai,af);

var pos=cspline(tau*(sum {j in 1..n} (h[j])),0,n,
      {j in 1..n}h[j], {j in 1..nk}knots[j],vi,vf,ai,af);


minimize obj:
  (sum {j in 1..n} (h[j]));

subject to tcons:
  -2 <= g <= 2;

# to plot in MATLAB
#subject to tcons1:
#   g <= 0;

#subject to tcons2:
#   pos <= 0;

subject to bounds {j in 1..n}:
  h[j] >= 0.01;

subject to tbounds:
  0 <= tau <= 1;

data;

# add data to problem (knots)
param knots :=
	1	0
	2	0.5
	3	0.75
	4	1
	5	0.75
	6	1.5;

# solution as initial guess
#param hinit :=
#1  0.281396
#2  0.0650184
#3  0.128647
#4  0.178947
#5  0.226906
#6  0.621131
#7  0.01;


param hinit :=
	1	1
	2	1
	3	0.5
	4	0.5
	5	0.5
	6	0.5
	7	0.5;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display h;
display obj;
