###############################################################################
# Objective: Linear
# Constraints: Generic
###############################################################################
#  Robotics path planning problem
#   As described by Elke Haaren-Retagne, PhD Thesis,
#                 submitted to Trier University, "A Semi-Infinite Programming
#                                   "Algorithm for Robot Trajectory Planning",
#                 1992
#   Originaly described by Ech-cherif, Ecker, Kupferschmid and Marin
#
#   Example 3A (model 1)
#    Coded by A. Ismael F. Vaz 01/03/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################
function bspline;
function dbspline;


param k;            # spline degree
param n;            # number of blend splines
# The number of knots can be changed, do not forget to change the Knots array
param nk;           # number of knots
param Knots{1..nk}; # knots
param c{1..3,1..3};
param epson;
param x0{1..n};     # starting guess
param t0;

var x{i in 1..n} := x0[i];  # x variables (coeficients in the spline)
var t := t0;                # spline parameter

# describe trajectory
param a{1..11,1..3};
param tKnots{1..17};

var teta1 =  bspline(t,    6, 11, {i in 1..11} a[i,1], {i in 1..17} tKnots[i]);
var teta1d1=dbspline(t, 1, 6, 11, {i in 1..11} a[i,1], {i in 1..17} tKnots[i]);
var teta1d2=dbspline(t, 2, 6, 11, {i in 1..11} a[i,1], {i in 1..17} tKnots[i]);
var teta1d3=dbspline(t, 3, 6, 11, {i in 1..11} a[i,1], {i in 1..17} tKnots[i]);

var teta2 =  bspline(t,    6, 11, {i in 1..11} a[i,2], {i in 1..17} tKnots[i]);
var teta2d1=dbspline(t, 1, 6, 11, {i in 1..11} a[i,2], {i in 1..17} tKnots[i]);
var teta2d2=dbspline(t, 2, 6, 11, {i in 1..11} a[i,2], {i in 1..17} tKnots[i]);
var teta2d3=dbspline(t, 3, 6, 11, {i in 1..11} a[i,2], {i in 1..17} tKnots[i]);

var teta3 =  bspline(t,    6, 11, {i in 1..11} a[i,3], {i in 1..17} tKnots[i]);
var teta3d1=dbspline(t, 1, 6, 11, {i in 1..11} a[i,3], {i in 1..17} tKnots[i]);
var teta3d2=dbspline(t, 2, 6, 11, {i in 1..11} a[i,3], {i in 1..17} tKnots[i]);
var teta3d3=dbspline(t, 3, 6, 11, {i in 1..11} a[i,3], {i in 1..17} tKnots[i]);


var g =	   bspline(t,    k, n, {i in 1..n} x[i], {i in 1..nk} Knots[i]);
var gd1 = dbspline(t, 1, k, n, {i in 1..n} x[i], {i in 1..nk} Knots[i]);
var gd2 = dbspline(t, 2, k, n, {i in 1..n} x[i], {i in 1..nk} Knots[i]);


minimize obj:
	(1/k)*(sum {i in 1..n} (x[i]*(Knots[i+k]-Knots[i])));

subject to bound:
	0 <= t <= 0.999999;

subject to tcons1:
	g - epson >= 0;

subject to tcons2j1:
	-1 <= teta1d1/(c[1,1]*g) <= 1;

subject to tcons2j2:
	-1 <= teta2d1/(c[2,1]*g) <= 1;

subject to tcons2j3:
	-1 <= teta3d1/(c[3,1]*g) <= 1;



subject to tcons3j1:
	-1 <= (teta1d2-teta1d1*(gd1/g))/(c[1,2]*(g)^2) <= 1;

subject to tcons3j2:
	-1 <= (teta2d2-teta2d1*(gd1/g))/(c[2,2]*(g)^2) <= 1;

subject to tcons3j3:
	-1 <= (teta3d2-teta3d1*(gd1/g))/(c[3,2]*(g)^2) <= 1;



subject to tcons4j1:
	-1 <= (teta1d3-3*teta1d2*(gd1/g)+teta1d1*((3*(gd1)^2-g*gd2)/(g)^2))/
		(c[1,3]*(g)^3) <= 1;

subject to tcons4j2:
	-1 <= (teta2d3-3*teta2d2*(gd1/g)+teta2d1*((3*(gd1)^2-g*gd2)/(g)^2))/
		(c[2,3]*(g)^3) <= 1;

subject to tcons4j3:
	-1 <= (teta3d3-3*teta3d2*(gd1/g)+teta3d1*((3*(gd1)^2-g*gd2)/(g)^2))/
		(c[3,3]*(g)^3) <= 1;


data;

# trajectory data
param a :
	1		2		3 :=
1	0.8353216	-0.4971999	2.803471
2	0.8353216	-0.4971999	2.803471
3	0.8353216	-0.4971999	2.803471
4	2.294404	-1.289908	2.137097
5	1.506865	-0.2470876	1.881815
6	0.8491478	 0.1336621	2.158783
7	0.5452022	 0.7745534	1.821837
8	0.1477306	-0.07365886	3.067521
9	1.227333	-0.4258067	2.340066
10	1.227333	-0.4258067	2.340066
11	1.227333	-0.4258067	2.340066;

param tKnots :=
	1	0
	2	0
	3	0
	4	0
	5	0
	6	0
	7	0.1754653
	8	0.3552259
	9	0.5061700
	10	0.6877756
	11	0.8319530
	12	1
	13	1
	14	1
	15	1
	16	1
	17	1;


param k  := 4;
param n  := 9;
param nk := 13;
param epson := 1D-2;
param Knots :=
	1	0
	2	0
	3	0
	4	0
	5	0.1666667
	6	0.3333333
	7	0.5
	8	0.6666667
	9	0.8333333
	10	1
	11	1
	12	1
	13	1;

param x0 := 
	1	2.84356
	2	2.84356
	3	2.84356
	4	2.84356
	5	2.84356
	6	2.84356
	7	2.84356
	8	2.84356
	9	2.84356;


param t0 := 0;


param c :
	1	2	3 :=
1	2	8	250
2	3	18	650
3	4	50	1000;


# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display obj;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "obj=%lf\n", 2.39669;

