###############################################################################
# Objective: Linear
# Constraints: Generic
###############################################################################
#
#   As described by Stephan Goerner in "Ein Hybridverfahren zur Loesung
#                         nichtlinearer semi-infiniter Optimierungsprobleme",
#   PhD. Dissertation, Berlin University, 1997
#
#   Example 16
#    Coded by A. Ismael F. Vaz 16/01/2002  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx;
#number of t
param nt;

# starting point (ampl needs also a starting point for t)
param xinit{1..nx};
param tinit{1..nt};

# x variables
var x {i in 1..nx} := xinit[i];
# t variable
var t {j in 1..nt} := tinit[j];

minimize fx:
	x[4];

subject to tcons1:
	exp(t[1])-(x[1]+x[2]*t[1])/(1+x[3]*t[1])-x[4] <=0;
subject to tcons2:
	-exp(t[1])+(x[1]+x[2]*t[1])/(1+x[3]*t[1])-x[4] <=0;
subject to bounds:
	0 <= t[1] <= 1;

data;

param nx := 4;
param nt := 1;

# watson starting point
param xinit :=
	1 1
	2 1
	3 1
	4 1;

param tinit :=
	1 0;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf,%lf,%lf) f=%lf\n", 0.995705, 0.668208, -0.388847, 0.004295, 0.004295;
