###############################################################################
# Objective: Linear
# Constraints: Generic
###############################################################################
#  Fractional semi-infinite programming problem
#  As described by Martin Gugat, PhD Thesis,
#   submitted to Trier University, "Fractional Semi-Infinite Programming", 1994
#
#   Example 12
#    Coded by A. Ismael F. Vaz 19/03/2002  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of z vars
param nz := 3;

# Gamma parameter
param gamma := 10^3;


# z variables
var z {1..nz};
# infinite variable
var t;
# d distance
var d;


# The functions
var f = atan(t);
var v = gamma*sin(z[1]*t)/10;
var w = gamma*z[3]*exp(-z[2]*t)/10;



minimize dp:
	d;

subject to tcons1:
	-(f-v/w)-d <= 0;
subject to tcons2:
	(f-v/w)-d <= 0;
subject to tcons3:
	-w <= -1;
subject to tcons4:
	w <= gamma;
subject to bounds:
	0 <= t <= 1;


###################
# End of Problem  #
###################


# don't forget to write .col and .row files
option nsips_auxfiles rc;
# this problem have no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display d;
display z;

# Gamma=10^3
printf "Original Solution\n";
printf "%lf,%lf,%lf\n", 0.86298770, -0.13827064, 0.84364224;