###############################################################################
# Objective: Linear
# Constraints: Quadratic
###############################################################################
#
#  Hettich problem to show the "shift term" in the second order optimality
#   conditions
#  As described by R. Hettich and K.O. Kortanek in "SEMI-INFINITE PROGRAMMING:
#		 THEORY, METHODS, AND APPLICATIONS",
#   SIAM Review, vol. 35, No. 3, pp. 380-429, September 1993
#
#   Example 5.3 page 395
#    Coded by A. Ismael F. Vaz 13/03/2003  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

#number of t
param nt := 1;
#number of x
param nx := 2;
#initial guess
param tinit {1..nt};
param xinit {1..nx};

# t variable
var t {i in 1..nt} := tinit[i];
# x variables
var x {i in 1..nx} := xinit[i];

minimize fx: # Minimization problem
	-(x[2]+5)^2-x[1]^2;

subject to tcons:
	2*t[1]*x[1]+x[2]-t[1]^2 <=0;
subject to bounds {i in 1..nt}:
	-1 <= t[i] <= 1;

data;

param xinit :=
# Local solution as initial guess
#	1	0
#	2	0;
	1	0
	2	-2.5;

param tinit :=
	1	0;



###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# change solver
option solver nsips;
# solve problem
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;
