###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Chebyshev approximation problem
#
#  As described by R. Hettich in "A review of numerical methods for
#		semi-infinite optimization"
#   in A.V. Fiacco and K.O. Kortanek (eds.), "Semi-infinite programming and
#		and applications",
#    Lecture notes in Economics and Mathematical Systems no.215, pp. 158-178
#    Springer Verlag, Berlin (1981)
#
#   Example (A) in page 163
#    Coded by A. Ismael F. Vaz 08/12/2003  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

#number of t
param nt := 2;
# degree of polinomial
param np := 4; # in Section 2 the degree used is 2.



# t variable
var t {1..nt};
# p variables
var p {i in 0..np, j in 0..i};
# distance
var d;

minimize fx:
	d;

subject to tcons1:
  (t[1]^t[2]-sum{i in 0..np} (sum{j in 0..i} (p[i,j]*t[1]^j*t[2]^(i-j))))-d<=0;
subject to tcons2:
 -(t[1]^t[2]-sum{i in 0..np} (sum{j in 0..i} (p[i,j]*t[1]^j*t[2]^(i-j))))-d<=0;
subject to bounds {i in 1..nt}:
	1 <= t[i] <= 2;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# change solver
option solver nsips;
# solve problem
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display p;
display fx;
