###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  As described by T. Leon, S. Sanmatias and E. Vercher,
#      "On the numerical treatment of linearly constrained semi-infinite
#                                optimization problems"
#    European Journal of Operational Research 121 (2000) 78-91
#
#   Example GU2, Appendix A
#
#    Coded by A. Ismael F. Vaz 04/03/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

#number of x vars
param nx;
#number of t vars
param nt;
# initial guess
param x0 {1..nx};
param t0 {1..nt};

param epson := -0.5;

# x variables
var x {i in 1..nx} := x0[i];
# t variable
var t {i in 1..nt} := t0[i];

minimize obj:
	x[1]+(1+epson)*x[2];

subject to tcons1:
	-1/(1+t[1])-x[1]-t[1]*x[2]<=0;
subject to bounds {i in 1..nt}:
	0 <= t[i] <= 1;


###################
# End of Problem  #
###################

data;

param nx := 2;
param nt := 1;

param x0 :=
	1	0
	2	0;

param t0 :=
	1	0;

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display obj;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
# if epson < 0
printf "x=(%lf,%lf) obj=%lf\n", -0.888600, 0.443867, -1/(2+epson);
# if epson = 0
#printf "obj=%lf\n", 0.5;
# if epson > 0 problem is unbounded
