###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Fuzzy set test problems
#  As described by T. Lon and E. Vercher, "Optimization under uncertainty
#                           and linear semi-infinite programming: a survey",#  
#  in M.A. Goberna and M.A.Lopez (eds.), "Semi-infinite Programming.
#     Recent Advances", Kluwer Academic Publishers, pp. 327-348 (2001)	
#
#   Example 3.1
#    Coded by J. Fernandes 10/11/2004  zefernandes@obando.org
#      aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx := 2;
#number of t vars
param nt := 1;
#initial guess
param x0 {1..nx};

# x variables
var x {i in 1..nx} := x0[i];
# t variable
var t {1..nt};


minimize fx:
	0.5*x[1]+x[2];

subject to tcons1:
	-(t[1]+1)^2*x[1]-(t[1]-2)^2*x[2] <=-1;

subject to bounds1 {i in 1..nt}:
	0 <= t[i] <= 1;

subject to bounds2 {i in 1..nx}:
	0 <= x[i];

###################
# End of Problem  #
###################

data;

param x0 :=
	1	1
        2       0;

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf) fx=%lf\n", 0.268245, 0.189679, 0.3238015;
