###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Fuzzy set test problems
#  As described by T. Lon and E. Vercher, "Optimization under uncertainty
#                           and linear semi-infinite programming: a survey",#  
#  in M.A. Goberna and M.A.Lopez (eds.), "Semi-infinite Programming.
#     Recent Advances", Kluwer Academic Publishers, pp. 327-348 (2001)	
#
#   Example 4.1
#    Coded by Rodolfo Carvalho Carvalhido 10/11/2004 
#      aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# d variable
var d;

# x variables
var x {1..3};

# t variable
var t;

# alfa parameter
param alpha:=0.6;


minimize fx:
	-x[1]-2*x[2]-2*x[3];	

subject to tcons1:
	-1*((2*t-4)*x[1]+(t-2)*t-t+9)<=0;

subject to tcons2:
	-1*((t-2)*x[3]-t+11)<=0;

subject to tcons3:
	-1*(-2*t*x[1]-t*x[2]+3*t+5)<=0;

subject to tcons4:
	-1*(-t*x[3]+2*t+8)<=0;

subject to bounds:
	alpha <= t <= 1;

subject to bounds1 {i in 1..3}:
	x[i] >= 0 ;


data;

var x:=
1 0
2 8
3 7;




###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# this problem have no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;


##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;


################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf,%lf) f=%lf\n", 0, 6, 7.428571,-26.857142 ;
printf "Or is it \n";
printf "x=(%lf,%lf,%lf) f=%lf ?\n", 0, 8, 7.428571, -30.857142;

