###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#  Design of FIR filters
#   As described by A.W. Potchinkov
#	"Design of optimal linear phase FIR filters by a semi-infinite
#	    programming technique"
#	 in Signal Processing 58 (1997) 165-180
#	
#   PLR design in pag. 173
#    Coded by A. Ismael F. Vaz 04/07/2000  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################
param pi := 4*atan(1);
param N := 241;
param R := (N-1)/2;


var x {0..R}; # coefficients
var t {1..2}; # infinite variable w (one for B1 and other for B2)
var d;        # delta (distance)

# U1 and U2 in B1 interval
param U1_1 := 0.9;
param U2_1 := 1.1;

# U1 and U2 in B2 interval
param U1_2 := -0.0001;
param U2_2 := 0.0001;

# A(a,w) in B1 and B2 intervals
var A1 = (sum {i in 0..R} (x[i]*cos(t[1]*i)));
var A2 = (sum {i in 0..R} (x[i]*cos(t[2]*i)));

# D(w) and d(w) in B1 and B2 intervals
param D1 := 0.5*(U2_1+U1_1);
param d1 := 0.5*(U2_1-U1_1);
param D2 := 0.5*(U2_2+U1_2);
param d2 := 0.5*(U2_2-U1_2);


minimize dp:
	d;

subject to t1:
	 A1-U2_1-d*(d1)<=0;
subject to t2:
	-A1+U1_1-d*(d1)<=0;

subject to t3:
	 A2-U2_2-d*(d2)<=0;
subject to t4:
	-A2+U1_2-d*(d2)<=0;

subject to bound1:
	0<= t[1] <= 0.2*pi;

subject to bound2:
	0.24*pi<= t[2] <= pi;


# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option reset_initial_guesses 1; # don't want a initial guess
option solver nsips;
solve;


display dp;

# Solution in MATLAB language
printf "x=\[";
for {i in 0..(R-1)} {
	printf "%f, ", x[i];
};
printf "%f\];\n", x[R];


	
