###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#
#  Reemtsen set of SIP problems (Chebyshev approximation problems)
#   As described by R. Reemtsen, "Discretization Methods for the Solution of
#                                 Semi-Infinite Programming Problems",
#   in Journal of Optimization Theory and Applications, vol. 71, No. 1, 1991
#
#   Example 4.3
#    Coded by A. Ismael F. Vaz 31/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# degree of polynomial d=2..5 were tested by Reemtsen
param d := 2;

#number of t
param nt := 3;

# x variables
var x {0..d,0..d,0..d};
# t variable
var t {1..nt};
# distance variable
var dist;

minimize distance:
	dist;

subject to tcons1:
	-(sum {i in 0..d} (
            sum {j in 0..d-i} (
	      sum {k in 0..d-i-j} (
		x[i,j,k]*(t[1]^i)*(t[2]^j)*(t[3]^k) )))
          -(cos(t[3])*(1+t[1])^t[2]))-dist <= 0;
subject to tcons2:
	(sum {i in 0..d} (
            sum {j in 0..d-i} (
	      sum {k in 0..d-i-j} (
		x[i,j,k]*(t[1]^i)*(t[2]^j)*(t[3]^k) )))
          -(cos(t[3])*(1+t[1])^t[2]))-dist <= 0;
subject to bound1:
	0 <= t[1] <= 1;
subject to bound2:
	1 <= t[2] <= 2;
subject to bound3:
	0 <= t[3] <= 1;


###################
# End of Problem  #
###################

# don't forget to write .col and .row files
option nsips_auxfiles rc;
# this problem have no initial guess (starting point)
option reset_initial_guesses 1;
# change solver
option solver nsips;
# solve problem
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display distance;


################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
# d=2
printf "distance=%lf\n", 1.52486e-1;
# d=3
#printf "distance=%lf\n", 3.11125e-2;
# d=4
#printf "distance=%lf\n", 4.87583e-3;
# d=5
#printf "distance=%lf\n", 7.08744e-4;
