###############################################################################
# Objective: Linear
# Constraints: Linear
###############################################################################
#  Watson set of SIP problems
#   As described by G.A. Watson in "Numerical Experiments with Globally
#                 Convergent Methods for Semi-Infinite Programming Problems",
#   Edited in Fiacco, A.V., and K.O. Kortanek (eds.),
#    "Semi-infinite Programming and Applications",
#    Lecture notes in Economics and Mathematical Systems no. 215, pp.193-205
#    Springer Verlag, Berlin (1983)
#
#   Example 8
#    Coded by A. Ismael F. Vaz 24/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
###############################################################################

# number of x vars
param nx;
#number of t
param nt;

# starting point (ampl needs also a starting point for t)
param xinit{1..nx};
param tinit{1..nt};

# x variables
var x {i in 1..nx} := xinit[i];
# t variable
var t {j in 1..nt} := tinit[j];

# watson had an error in one of the coeficients in the objective function, watch out!!!
# Price thesis is correct...

minimize fx:
	x[1]+(1/2)*x[2]+(1/2)*x[3]+(1/3)*x[4]+(1/4)*x[5]+(1/3)*x[6];

subject to tcons:
	exp(t[1]^2+t[2]^2)-(x[1]+x[2]*t[1]+x[3]*t[2]+x[4]*t[1]^2+x[5]*t[1]*t[2]+x[6]*t[2]^2) <= 0;

subject to bounds {i in 1..nt}:
	0 <= t[i] <= 1;


data;

param nx := 6;
param nt := 2;

# watson starting point
param xinit :=
	1 0
	2 0
	3 0
	4 0
	5 0
	6 0;

param tinit :=
	1 0
	2 0;

# solve problem
# don't forget to write .col and .row files
option nsips_auxfiles rc;
option solver nsips;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display x;
display fx;

################################################
# solution of problem presented by the authors #
################################################
printf "Original Solution\n";
printf "x=(%lf,%lf,%lf,%lf,%lf,%lf) f=%lf\n", 2.580159, -4.109280, -4.109281, 4.247403, 4.532651, 4.247404, 2.435644;
